# SessionChallengeStatus

Session Challenge

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**description** | **str** | Description to user as to which can provide info such as which resource this session challege is associated with.  | [optional] 
**challenge** | [**Challenge**](Challenge.md) |  | [optional] 
**session** | [**Session**](Session.md) |  | [optional] 
**webauthn_enrollments** | [**[WebAuthNEnrollment]**](WebAuthNEnrollment.md) | webauthn enrollments  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


